import { AxiosResponse } from "axios";
import { IError } from "../../interface";
export interface IAddOrderParams {
    add_source: number;
    wx_appid?: string;
    order_id: string;
    openid?: string;
    delivery_id: string;
    biz_id: string;
    custom_remark?: string;
    tagid?: number;
    sender: ISender;
    receiver: IReceiver;
    cargo: ICargo;
    shop: IShop;
    insured: IInsured;
    service: IService;
    expect_time?: number;
}
export interface ISender {
    name: string;
    tel?: string;
    mobile?: string;
    company?: string;
    post_code?: string;
    country?: string;
    province: string;
    city: string;
    area: string;
    address: string;
}
export interface IReceiver {
    name: string;
    tel?: string;
    mobile?: string;
    company?: string;
    post_code?: string;
    country?: string;
    province: string;
    city: string;
    area: string;
    address: string;
}
export interface ICargo {
    count: number;
    weight: number;
    space_x: number;
    space_y: number;
    space_z: number;
    detail_list: ICargoDetail[];
}
export interface ICargoDetail {
    name: string;
    count: number;
}
export interface IShop {
    wxa_path: string;
    img_url: string;
    goods_name: string;
    goods_count: number;
}
export interface IInsured {
    use_insured: number;
    insured_value: number;
}
export interface IService {
    service_type: number;
    service_name: string;
}
export interface IExpressOrder {
    order_id: string;
    waybill_id: string;
    waybill_data: IWaybillData;
    delivery_resultcode: number;
    delivery_resultmsg: string;
}
export interface IWaybillData {
    key: string;
    value: string;
}
export declare type IOrder = {
    order_id: string;
    delivery_id: string;
    waybill_id: string;
    print_html?: string;
    waybill_data?: IWaybillData[];
    order_status?: number;
};
export interface IGetParams {
    order_id?: string;
    openid?: string;
    delivery_id: string;
    waybill_id?: string;
}
export declare type IGetPathParams = IGetParams;
export declare type IGetOrderParams = IGetParams;
export interface IPathItemList {
    action_time: number;
    action_type: 100001 | 100002 | 100003 | 200001 | 300002 | 300003 | 300004 | 400001 | 400002;
    action_msg: string;
}
export declare type IGetPrinterResponse = AxiosResponse<IError & {
    count: number;
    openid: Array<string>;
    tagid_list: Array<string>;
}>;
export declare type IGetAllDeliveryResponse = AxiosResponse<IError & {
    count: number;
    data: Array<{
        delivery_id: string;
        delivery_name: string;
        can_use_cash: number;
        can_get_quota: number;
        cash_biz_id: string;
        service_type: Array<IService>;
    }>;
}>;
export declare type IGetAllAccountResponse = AxiosResponse<IError & {
    count: number;
    list: Array<{
        biz_id: string;
        delivery_id: string;
        create_time: number;
        update_time: number;
        status_code: number;
        alias: string;
        remark_wrong_msg: string;
        remark_content: string;
        quota_num: number;
        quota_update_time: number;
        service_type: Array<IService>;
    }>;
}>;
export declare type IAddOrderResponse = AxiosResponse<IError & IExpressOrder>;
export declare type IBatchGetOrderResponse = AxiosResponse<IError & {
    order_list: Array<IError & IOrder>;
}>;
export declare type IGetOrderResponse = AxiosResponse<IError & IOrder>;
export declare type IGetPathResponse = AxiosResponse<IError & {
    openid: string;
    delivery_id: string;
    waybill_id: string;
    path_item_num: number;
    path_item_list: Array<IPathItemList>;
}>;
export declare type IGetQuotaResponse = AxiosResponse<IError & {
    quota_num: number;
}>;
