"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Urlscheme = void 0;
/**
 * 获取小程序scheme码
 * https://developers.weixin.qq.com/miniprogram/dev/framework/open-ability/url-scheme.html
 * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/url-scheme/urlscheme.generate.html
 */
class Urlscheme {
    constructor(mini) {
        this.mini = mini;
    }
    /**
     * 获取小程序scheme码
     * - 单个小程序每日生成Scheme上限为50万个（包含短期有效Scheme与长期有效Scheme）
     * - 有效时间超过31天的Scheme或永久有效的Scheme为长期有效Scheme，单个小程序总共可生成长期有效Scheme上限为10万个，请谨慎调用
     * - 有效时间不超过31天的Scheme为短期有效Scheme，单个小程序生成短期有效Scheme不设上限
     * - scheme weixin://dl/business/?t= *TICKET*
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/url-scheme/urlscheme.generate.html
     */
    generate(body) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "/wxa/generatescheme";
            const resp = yield this.mini.http.post(url, body);
            console.log(resp);
            if (resp.data.errcode) {
                throw new Error(`获取小程序scheme码失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
}
exports.Urlscheme = Urlscheme;
